@@ -922,7 +922,7 @@ ges_asset_set_id (GESAsset * asset, const gchar * id)
 }
 
 static GESAsset *
-_unsure_material_for_wrong_id (const gchar * wrong_id, GType extractable_type,
+_ensure_asset_for_wrong_id (const gchar * wrong_id, GType extractable_type,
     GError * error)
 {
   GESAsset *asset;
@@ -994,7 +994,7 @@ ges_asset_request (GType extractable_type, const gchar * id, GError ** error)
   if (real_id == NULL) {
     /* We create an asset for that wrong ID so we have a reference that the
      * user requested it */
-    _unsure_material_for_wrong_id (id, extractable_type, lerr);
+    _ensure_asset_for_wrong_id (id, extractable_type, lerr);
     real_id = g_strdup (id);
   }
   if (lerr)
@@ -1127,6 +1127,7 @@ ges_asset_request_async (GType extractable_type,
   gchar *real_id;
   GESAsset *asset;
   GError *error = NULL;
+  GTask *task = NULL;
 
   g_return_if_fail (g_type_is_a (extractable_type, G_TYPE_OBJECT));
   g_return_if_fail (g_type_is_a (extractable_type, GES_TYPE_EXTRACTABLE));
@@ -1137,22 +1138,20 @@ ges_asset_request_async (GType extractable_type,
 
   real_id = _check_and_update_parameters (&extractable_type, id, &error);
   if (error) {
-    _unsure_material_for_wrong_id (id, extractable_type, error);
+    _ensure_asset_for_wrong_id (id, extractable_type, error);
     real_id = g_strdup (id);
   }
 
   /* Check if we already have an asset for this ID */
   asset = ges_asset_cache_lookup (extractable_type, real_id);
   if (asset) {
-    GTask *task = g_task_new (asset, NULL, callback, user_data);
+    task = g_task_new (asset, NULL, callback, user_data);
 
     /* In the case of proxied asset, we will loop until we find the
      * last asset of the chain of proxied asset */
     while (TRUE) {
       switch (asset->priv->state) {
         case ASSET_INITIALIZED:
-          gst_object_ref (asset);
-
           GST_DEBUG_OBJECT (asset, "Asset in cache and initialized, "
               "using it");
 
@@ -1164,6 +1163,7 @@ ges_asset_request_async (GType extractable_type,
           GST_DEBUG_OBJECT (asset, "Asset in cache and but not "
               "initialized, setting a new callback");
           ges_asset_cache_append_task (extractable_type, real_id, task);
+          task = NULL;
 
           goto done;
         case ASSET_PROXIED:{
@@ -1182,12 +1182,15 @@ ges_asset_request_async (GType extractable_type,
         case ASSET_NEEDS_RELOAD:
           GST_DEBUG_OBJECT (asset, "Asset in cache and needs reload");
           ges_asset_cache_append_task (extractable_type, real_id, task);
+          task = NULL;
           GES_ASSET_GET_CLASS (asset)->start_loading (asset, &error);
 
           goto done;
         case ASSET_INITIALIZED_WITH_ERROR:
           g_task_return_error (task,
-              error ? error : g_error_copy (asset->priv->error));
+              error ? g_error_copy (error) : g_error_copy (asset->priv->error));
+
+          g_clear_error (&error);
 
           goto done;
         default:
@@ -1201,6 +1204,8 @@ ges_asset_request_async (GType extractable_type,
       (extractable_type), G_PRIORITY_DEFAULT, cancellable, callback, user_data,
       "id", real_id, "extractable-type", extractable_type, NULL);
 done:
+  if (task)
+    gst_object_unref (task);
   if (real_id)
     g_free (real_id);
 }
@@ -1232,7 +1237,7 @@ ges_asset_needs_reload (GType extractable_type, const gchar * id)
 
   real_id = _check_and_update_parameters (&extractable_type, id, &error);
   if (error) {
-    _unsure_material_for_wrong_id (id, extractable_type, error);
+    _ensure_asset_for_wrong_id (id, extractable_type, error);
     real_id = g_strdup (id);
   }
 
