@@ -46,6 +46,10 @@ neighbour_changed_cb (GESClip * clip, GParamSpec * arg G_GNUC_UNUSED,
   GESTimelineElement *parent =
       ges_timeline_element_get_toplevel_parent (GES_TIMELINE_ELEMENT (clip));
 
+  if (ELEMENT_FLAG_IS_SET (parent, GES_TIMELINE_ELEMENT_SET_SIMPLE)) {
+    return;
+  }
+
   if (parent) {
     GESTimelineElement *prev_topparent =
         ges_timeline_element_get_toplevel_parent (GES_TIMELINE_ELEMENT
@@ -54,6 +58,11 @@ neighbour_changed_cb (GESClip * clip, GParamSpec * arg G_GNUC_UNUSED,
         ges_timeline_element_get_toplevel_parent (GES_TIMELINE_ELEMENT
         (self->previous_source));
 
+    if (ELEMENT_FLAG_IS_SET (prev_topparent, GES_TIMELINE_ELEMENT_SET_SIMPLE) ||
+        ELEMENT_FLAG_IS_SET (next_topparent, GES_TIMELINE_ELEMENT_SET_SIMPLE)) {
+      return;
+    }
+
     if (parent == prev_topparent && parent == next_topparent) {
       GST_DEBUG_OBJECT (self,
           "Moving all inside the same group, nothing to do");
@@ -61,8 +70,8 @@ neighbour_changed_cb (GESClip * clip, GParamSpec * arg G_GNUC_UNUSED,
     }
   }
 
-  if (_ges_track_element_get_layer_priority (self->next_source) !=
-      _ges_track_element_get_layer_priority (self->previous_source)) {
+  if (GES_TIMELINE_ELEMENT_LAYER_PRIORITY (self->next_source) !=
+      GES_TIMELINE_ELEMENT_LAYER_PRIORITY (self->previous_source)) {
     GST_DEBUG_OBJECT (self, "Destroy changed layer");
     g_signal_emit (self, auto_transition_signals[DESTROY_ME], 0);
     return;
@@ -192,3 +201,11 @@ ges_auto_transition_new (GESTrackElement * transition,
 
   return self;
 }
+
+void
+ges_auto_transition_update (GESAutoTransition * self)
+{
+  GST_INFO ("Updating info %s",
+      GES_TIMELINE_ELEMENT_NAME (self->transition_clip));
+  neighbour_changed_cb (self->previous_clip, NULL, self);
+}
