@@ -139,6 +139,9 @@ struct _GESBaseXmlFormatterPrivate
   GList *groups;
 };
 
+static void
+_free_pending_clip (GESBaseXmlFormatterPrivate * priv, PendingClip * pend);
+
 static void
 _free_layer_entry (LayerEntry * entry)
 {
@@ -146,6 +149,15 @@ _free_layer_entry (LayerEntry * entry)
   g_slice_free (LayerEntry, entry);
 }
 
+static void
+_free_pending_group (PendingGroup * pgroup)
+{
+  if (pgroup->group)
+    g_object_unref (pgroup->group);
+  g_list_free_full (pgroup->pending_children, g_free);
+  g_slice_free (PendingGroup, pgroup);
+}
+
 /*
 enum
 {
@@ -350,6 +362,12 @@ static void
 _dispose (GObject * object)
 {
   GESBaseXmlFormatterPrivate *priv = _GET_PRIV (object);
+  GList *pendings, *pending_clips_lists;
+
+  pending_clips_lists = g_hash_table_get_values (priv->assetid_pendingclips);
+  for (pendings = pending_clips_lists; pendings; pendings = pendings->next)
+    g_list_free_full (pendings, (GDestroyNotify) _free_pending_clip);
+  g_list_free (pending_clips_lists);
 
   g_clear_pointer (&priv->assetid_pendingclips, g_hash_table_unref);
   g_clear_pointer (&priv->containers, g_hash_table_unref);
@@ -368,6 +386,9 @@ _finalize (GObject * object)
   if (priv->parsecontext != NULL)
     g_markup_parse_context_free (priv->parsecontext);
 
+  g_list_free_full (priv->groups, (GDestroyNotify) _free_pending_group);
+  priv->groups = NULL;
+
   G_OBJECT_CLASS (parent_class)->finalize (object);
 }
 
@@ -464,7 +485,11 @@ _add_all_groups (GESFormatter * self)
           GES_TIMELINE_ELEMENT_NAME (child));
       ges_container_add (GES_CONTAINER (pgroup->group), child);
     }
+    pgroup->group = NULL;
   }
+
+  g_list_free_full (priv->groups, (GDestroyNotify) _free_pending_group);
+  priv->groups = NULL;
 }
 
 static void
@@ -488,7 +513,7 @@ _loading_done (GESFormatter * self)
   for (tmp = assets; tmp; tmp = tmp->next) {
     ges_asset_set_proxy (NULL, tmp->data);
   }
-  g_list_free (assets);
+  g_list_free_full (assets, g_object_unref);
 
   g_hash_table_foreach (priv->layers, (GHFunc) _set_auto_transition, NULL);
   ges_project_set_loaded (self->project, self);
@@ -719,9 +744,6 @@ new_asset_cb (GESAsset * source, GAsyncResult * res, PendingAsset * passet)
           error->message);
 
       pendings = g_hash_table_lookup (priv->assetid_pendingclips, id);
-      for (tmp = pendings; tmp; tmp = tmp->next)
-        _free_pending_clip (priv, (PendingClip *) tmp->data);
-
       _free_pending_asset (priv, passet);
       goto done;
     }
@@ -781,7 +803,6 @@ new_asset_cb (GESAsset * source, GAsyncResult * res, PendingAsset * passet)
       _add_track_element (self, clip, gst_object_ref (peffect->trackelement),
           peffect->track_id, peffect->children_properties, peffect->properties);
     }
-    _free_pending_clip (priv, pend);
   }
 
   /* And now add to the project */
@@ -796,7 +817,11 @@ done:
   if (possible_id)
     g_free (possible_id);
 
+  g_clear_error (&error);
+
   if (pendings) {
+    for (tmp = pendings; tmp; tmp = tmp->next)
+      _free_pending_clip (priv, tmp->data);
     g_hash_table_remove (priv->assetid_pendingclips, id);
     g_list_free (pendings);
   }
