@@ -665,16 +665,16 @@ _deep_copy (GESTimelineElement * element, GESTimelineElement * copy)
   GList *tmp;
   GESClip *self = GES_CLIP (element), *ccopy = GES_CLIP (copy);
 
+  if (!self->priv->layer)
+    return;
+
   for (tmp = GES_CONTAINER_CHILDREN (element); tmp; tmp = tmp->next) {
     ccopy->priv->copied_track_elements =
         g_list_append (ccopy->priv->copied_track_elements,
         ges_timeline_element_copy (tmp->data, TRUE));
   }
 
-  if (self->priv->copied_layer)
-    ccopy->priv->copied_layer = g_object_ref (self->priv->copied_layer);
-  else if (self->priv->layer)
-    ccopy->priv->copied_layer = g_object_ref (self->priv->layer);
+  ccopy->priv->copied_layer = g_object_ref (self->priv->layer);
 }
 
 static GESTimelineElement *
@@ -693,7 +693,6 @@ _paste (GESTimelineElement * element, GESTimelineElement * ref,
     if (!ges_layer_add_clip (self->priv->copied_layer, nclip)) {
       GST_INFO ("%" GES_FORMAT " could not be pasted to %" GST_TIME_FORMAT,
           GES_ARGS (element), GST_TIME_ARGS (paste_position));
-      gst_object_unref (nclip);
 
       return NULL;
     }
