@@ -34,11 +34,13 @@
 
 G_BEGIN_DECLS
 
-GST_DEBUG_CATEGORY_EXTERN (_ges_debug);
 #ifndef GST_CAT_DEFAULT
-#define GST_CAT_DEFAULT _ges_debug
+#define GST_CAT_DEFAULT (_ges_debug ())
 #endif
 
+G_GNUC_INTERNAL
+GstDebugCategory * _ges_debug (void);
+
 /*  The first 2 NLE priorities are used for:
  *    0- The Mixing element
  *    1- The Gaps
