@@ -27,6 +27,10 @@
  *
  * Deprecated: 1.0
  */
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#undef VERSION
+#endif
 
 #include <libxml/xmlreader.h>
 #include <libxml/tree.h>
@@ -37,14 +41,13 @@
 #include <libxml/xmlwriter.h>
 
 #include "ges-internal.h"
+#include <ges/ges-pitivi-formatter.h>
 #include <ges/ges.h>
 
 /* The Pitivi etree formatter is 0.1 we set GES one to 0.2 */
-#define VERSION "0.2"
+//#define VERSION "0.2"
 #define DOUBLE_VERSION 0.2
 
-G_DEFINE_TYPE (GESPitiviFormatter, ges_pitivi_formatter, GES_TYPE_FORMATTER);
-
 #undef GST_CAT_DEFAULT
 GST_DEBUG_CATEGORY_STATIC (ges_pitivi_formatter_debug);
 #define GST_CAT_DEFAULT ges_pitivi_formatter_debug
@@ -94,6 +97,10 @@ struct _GESPitiviFormatterPrivate
   guint nb_sources;
 };
 
+G_DEFINE_TYPE_WITH_PRIVATE (GESPitiviFormatter, ges_pitivi_formatter,
+    GES_TYPE_FORMATTER);
+
+
 static void
 list_table_destroyer (gpointer key, gpointer value, void *unused)
 {
@@ -714,7 +721,6 @@ ges_pitivi_formatter_class_init (GESPitiviFormatterClass * klass)
 
   object_class = G_OBJECT_CLASS (klass);
   formatter_klass = GES_FORMATTER_CLASS (klass);
-  g_type_class_add_private (klass, sizeof (GESPitiviFormatterPrivate));
 
   formatter_klass->can_load_uri = pitivi_can_load_uri;
   formatter_klass->save_to_uri = NULL;
@@ -731,8 +737,7 @@ ges_pitivi_formatter_init (GESPitiviFormatter * self)
 {
   GESPitiviFormatterPrivate *priv;
 
-  self->priv = G_TYPE_INSTANCE_GET_PRIVATE (self,
-      GES_TYPE_PITIVI_FORMATTER, GESPitiviFormatterPrivate);
+  self->priv = ges_pitivi_formatter_get_instance_private (self);
 
   priv = self->priv;
 
