@@ -370,7 +370,6 @@ ges_uri_assets_validate_uri (const gchar * nid)
 static void
 _dispose (GObject * object)
 {
-  GList *tmp;
   GESProjectPrivate *priv = GES_PROJECT (object)->priv;
 
   if (priv->assets)
@@ -382,8 +381,8 @@ _dispose (GObject * object)
   if (priv->formatter_asset)
     gst_object_unref (priv->formatter_asset);
 
-  for (tmp = priv->formatters; tmp; tmp = tmp->next)
-    ges_project_remove_formatter (GES_PROJECT (object), tmp->data);;
+  while (priv->formatters)
+    ges_project_remove_formatter (GES_PROJECT (object), priv->formatters->data);
 
   G_OBJECT_CLASS (ges_project_parent_class)->dispose (object);
 }
@@ -395,6 +394,7 @@ _finalize (GObject * object)
 
   if (priv->uri)
     g_free (priv->uri);
+  g_list_free_full (priv->encoding_profiles, g_object_unref);
 
   G_OBJECT_CLASS (ges_project_parent_class)->finalize (object);
 }
@@ -635,6 +635,7 @@ new_asset_cb (GESAsset * source, GAsyncResult * res, GESProject * project)
 
   if (error) {
     possible_id = ges_project_try_updating_id (project, source, error);
+    g_clear_error (&error);
 
     if (possible_id == NULL)
       return;
@@ -643,7 +644,6 @@ new_asset_cb (GESAsset * source, GAsyncResult * res, GESProject * project)
         ges_asset_get_extractable_type (source));
 
     g_free (possible_id);
-    g_error_free (error);
     return;
   }
 
