@@ -1825,7 +1825,8 @@ ges_timeline_element_get_track_types (GESTimelineElement * self)
  * using ges_timeline_element_copy with recurse=TRUE set,
  * otherwise it will fail.
  *
- * Returns: (transfer none): Paste @self copying the element
+ * Returns: (transfer full): New element resulting of pasting @self
+ * or %NULL
  *
  * Since: 1.6.0
  */
@@ -1853,7 +1854,7 @@ ges_timeline_element_paste (GESTimelineElement * self,
 
   g_clear_object (&self->priv->copied_from);
 
-  return g_object_ref (res);
+  return res ? g_object_ref (res) : res;
 }
 
 /**
@@ -1863,6 +1864,8 @@ ges_timeline_element_paste (GESTimelineElement * self,
  * Returns: The priority of the first layer the element is in (note that only
  * groups can span over several layers). %GES_TIMELINE_ELEMENT_NO_LAYER_PRIORITY
  * means that the element is not in a layer.
+ *
+ * Since: 1.16
  */
 guint32
 ges_timeline_element_get_layer_priority (GESTimelineElement * self)
