@@ -98,9 +98,12 @@ ges_transition_clip_update_vtype_internal (GESClip *
   trself->priv->vtype_name = asset_id;
 
   if (set_asset) {
-    /* We already checked the value, so we can be sure no error will accured */
-    ges_extractable_set_asset (GES_EXTRACTABLE (self),
-        ges_asset_request (GES_TYPE_TRANSITION_CLIP, asset_id, NULL));
+    GESAsset *asset =
+        ges_asset_request (GES_TYPE_TRANSITION_CLIP, asset_id, NULL);
+
+    /* We already checked the value, so we can be sure no error occurred */
+    ges_extractable_set_asset (GES_EXTRACTABLE (self), asset);
+    gst_object_unref (asset);
   }
 }
 
