@@ -19,9 +19,13 @@
 
 /**
  * SECTION:ges-utils
+ * @title: GES utilities
  * @short_description: Convenience methods
  *
  */
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
 
 #include <string.h>
 
