@@ -168,12 +168,10 @@ nle_operation_class_init (NleOperationClass * klass)
   nleobject_class->prepare = GST_DEBUG_FUNCPTR (nle_operation_prepare);
   nleobject_class->cleanup = GST_DEBUG_FUNCPTR (nle_operation_cleanup);
 
-  gst_element_class_add_pad_template (gstelement_class,
-      gst_static_pad_template_get (&nle_operation_src_template));
-
-  gst_element_class_add_pad_template (gstelement_class,
-      gst_static_pad_template_get (&nle_operation_sink_template));
-
+  gst_element_class_add_static_pad_template (gstelement_class,
+      &nle_operation_src_template);
+  gst_element_class_add_static_pad_template (gstelement_class,
+      &nle_operation_sink_template);
 }
 
 static void
@@ -666,6 +664,7 @@ static gboolean
 remove_sink_pad (NleOperation * operation, GstPad * sinkpad)
 {
   gboolean ret = TRUE;
+  gboolean need_unref = FALSE;
 
   GST_DEBUG ("sinkpad %s:%s", GST_DEBUG_PAD_NAME (sinkpad));
 
@@ -681,6 +680,7 @@ remove_sink_pad (NleOperation * operation, GstPad * sinkpad)
       ret = FALSE;
       goto beach;
     }
+    need_unref = TRUE;
   }
 
   if (sinkpad) {
@@ -695,6 +695,8 @@ remove_sink_pad (NleOperation * operation, GstPad * sinkpad)
     }
     operation->sinks = g_list_remove (operation->sinks, sinkpad);
     nle_object_remove_ghost_pad ((NleObject *) operation, sinkpad);
+    if (need_unref)
+      gst_object_unref (sinkpad);
     operation->realsinks--;
   }
 
