@@ -29,9 +29,13 @@ GST_START_TEST (test_effect_basic)
 {
   GESEffect *effect;
 
+  ges_init ();
+
   effect = ges_effect_new ("agingtv");
   fail_unless (effect != NULL);
   gst_object_unref (effect);
+
+  ges_deinit ();
 }
 
 GST_END_TEST;
@@ -44,6 +48,8 @@ GST_START_TEST (test_add_effect_to_clip)
   GESEffect *effect;
   GESTestClip *source;
 
+  ges_init ();
+
   timeline = ges_timeline_new ();
   layer = ges_layer_new ();
   track_audio = GES_TRACK (ges_audio_track_new ());
@@ -74,6 +80,8 @@ GST_START_TEST (test_add_effect_to_clip)
   ges_layer_remove_clip (layer, (GESClip *) source);
 
   gst_object_unref (timeline);
+
+  ges_deinit ();
 }
 
 GST_END_TEST;
@@ -89,6 +97,8 @@ GST_START_TEST (test_get_effects_from_tl)
   GList *effects, *tmp = NULL;
   gint effect_prio = -1;
 
+  ges_init ();
+
   timeline = ges_timeline_new ();
   layer = ges_layer_new ();
   track_video = GES_TRACK (ges_video_track_new ());
@@ -160,6 +170,8 @@ GST_START_TEST (test_get_effects_from_tl)
   ges_layer_remove_clip (layer, (GESClip *) source);
 
   gst_object_unref (timeline);
+
+  ges_deinit ();
 }
 
 GST_END_TEST;
@@ -180,6 +192,8 @@ GST_START_TEST (test_effect_clip)
     GES_TRACK_TYPE_AUDIO
   };
 
+  ges_init ();
+
   timeline = ges_timeline_new ();
   layer = ges_layer_new ();
   track_audio = GES_TRACK (ges_audio_track_new ());
@@ -231,6 +245,8 @@ GST_START_TEST (test_effect_clip)
   ges_layer_remove_clip (layer, (GESClip *) effect_clip);
 
   gst_object_unref (timeline);
+
+  ges_deinit ();
 }
 
 GST_END_TEST;
@@ -246,6 +262,8 @@ GST_START_TEST (test_priorities_clip)
 
   gint effect_prio = -1;
 
+  ges_init ();
+
   timeline = ges_timeline_new ();
   layer = ges_layer_new ();
   track_audio = GES_TRACK (ges_audio_track_new ());
@@ -342,6 +360,8 @@ GST_START_TEST (test_priorities_clip)
   ges_layer_remove_clip (layer, (GESClip *) effect_clip);
 
   gst_object_unref (timeline);
+
+  ges_deinit ();
 }
 
 GST_END_TEST;
@@ -359,6 +379,8 @@ GST_START_TEST (test_effect_set_properties)
   GValue val = { 0 };
   GValue nval = { 0 };
 
+  ges_init ();
+
   timeline = ges_timeline_new ();
   layer = ges_layer_new ();
   track_video = GES_TRACK (ges_video_track_new ());
@@ -412,6 +434,8 @@ GST_START_TEST (test_effect_set_properties)
   ges_layer_remove_clip (layer, (GESClip *) effect_clip);
 
   gst_object_unref (timeline);
+
+  ges_deinit ();
 }
 
 GST_END_TEST;
@@ -444,6 +468,8 @@ GST_START_TEST (test_clip_signals)
   GValue val = { 0, };
   gboolean effect_added = FALSE;
 
+  ges_init ();
+
   timeline = ges_timeline_new ();
   layer = ges_layer_new ();
   track_video = GES_TRACK (ges_video_track_new ());
@@ -482,6 +508,8 @@ GST_START_TEST (test_clip_signals)
   ges_layer_remove_clip (layer, (GESClip *) effect_clip);
 
   gst_object_unref (timeline);
+
+  ges_deinit ();
 }
 
 GST_END_TEST;
@@ -495,6 +523,8 @@ GST_START_TEST (test_split_clip_effect_priorities)
   GESEffect *effect;
   GESTrackElement *source, *nsource, *neffect;
 
+  ges_init ();
+
   timeline = ges_timeline_new ();
   layer = ges_layer_new ();
   track_video = GES_TRACK (ges_video_track_new ());
@@ -534,6 +564,8 @@ GST_START_TEST (test_split_clip_effect_priorities)
   assert_equals_uint64 (GES_TIMELINE_ELEMENT_PRIORITY (nsource), 6);
 
   gst_object_unref (timeline);
+
+  ges_deinit ();
 }
 
 GST_END_TEST;
@@ -545,12 +577,6 @@ ges_suite (void)
   Suite *s = suite_create ("ges");
   TCase *tc_chain = tcase_create ("effect");
 
-  ges_init ();
-
-  if (atexit (ges_deinit) != 0) {
-    GST_ERROR ("failed to set ges_deinit as exit function");
-  }
-
   suite_add_tcase (s, tc_chain);
 
   tcase_add_test (tc_chain, test_effect_basic);
