@@ -57,17 +57,19 @@ fill_pipeline_and_check (GstElement * comp, GList * segments,
           break;
         case GST_MESSAGE_ERROR:
         {
-          GError *error;
+          GError *error = NULL;
 
           gst_message_parse_error (message, &error, NULL);
           if (comp == GST_ELEMENT (GST_MESSAGE_SRC (message)) &&
               expected_error_domain == error->domain) {
             GST_DEBUG ("Expected Error Message from %s : %s",
                 GST_OBJECT_NAME (GST_MESSAGE_SRC (message)), error->message);
-
             carry_on = FALSE;
-          } else
-            fail_error_message (message);
+          } else {
+            fail_unless (FALSE, "Error Message from %s : %s",
+                GST_OBJECT_NAME (GST_MESSAGE_SRC (message)), error->message);
+          }
+          g_clear_error (&error);
         }
           break;
         default:
@@ -88,6 +90,10 @@ fill_pipeline_and_check (GstElement * comp, GList * segments,
 
   GST_DEBUG ("Resetted pipeline to READY");
 
+  if (collect->seen_segments)
+    g_list_free (collect->seen_segments);
+
+  collect->seen_segments = NULL;
   collect->expected_segments = listcopy;
   collect->gotsegment = FALSE;
   collect->expected_base = 0;
@@ -141,7 +147,7 @@ done:
   ASSERT_OBJECT_REFCOUNT_BETWEEN (bus, "main bus", 1, 2);
   gst_object_unref (bus);
 
-  g_free (collect);
+  collect_free (collect);
 }
 
 GST_START_TEST (test_one_space_another)
@@ -150,6 +156,8 @@ GST_START_TEST (test_one_space_another)
   gboolean ret = FALSE;
   GList *segments = NULL;
 
+  ges_init ();
+
   comp =
       gst_element_factory_make_or_warn ("nlecomposition", "test_composition");
   gst_element_set_state (comp, GST_STATE_READY);
@@ -219,6 +227,8 @@ GST_START_TEST (test_one_space_another)
       segment_new (1.0, GST_FORMAT_TIME, 0, 1 * GST_SECOND, 0));
 
   fill_pipeline_and_check (comp, segments, GST_STREAM_ERROR);
+
+  ges_deinit ();
 }
 
 GST_END_TEST;
@@ -229,6 +239,8 @@ GST_START_TEST (test_one_default_another)
   GstElement *comp, *source1, *source2, *source3, *defaultsrc;
   GList *segments = NULL;
 
+  ges_init ();
+
   comp =
       gst_element_factory_make_or_warn ("nlecomposition", "test_composition");
   gst_element_set_state (comp, GST_STATE_READY);
@@ -336,6 +348,8 @@ GST_START_TEST (test_one_default_another)
           4 * GST_SECOND, 5 * GST_SECOND, 4 * GST_SECOND));
 
   fill_pipeline_and_check (comp, segments, GST_STREAM_ERROR);
+
+  ges_deinit ();
 }
 
 GST_END_TEST;
@@ -346,6 +360,8 @@ GST_START_TEST (test_one_expandable_another)
   GList *segments = NULL;
   gboolean ret = FALSE;
 
+  ges_init ();
+
   comp =
       gst_element_factory_make_or_warn ("nlecomposition", "test_composition");
   gst_element_set_state (comp, GST_STATE_READY);
@@ -458,6 +474,8 @@ GST_START_TEST (test_one_expandable_another)
           4 * GST_SECOND, 5 * GST_SECOND, 4 * GST_SECOND));
 
   fill_pipeline_and_check (comp, segments, 0);
+
+  ges_deinit ();
 }
 
 GST_END_TEST;
@@ -477,6 +495,8 @@ GST_START_TEST (test_renegotiation)
   GstPad *sinkpad;
   GstCaps *caps;
 
+  ges_init ();
+
   pipeline = gst_pipeline_new ("test_pipeline");
   comp =
       gst_element_factory_make_or_warn ("nlecomposition", "test_composition");
@@ -614,6 +634,10 @@ GST_START_TEST (test_renegotiation)
 
   GST_DEBUG ("Resetted pipeline to READY");
 
+  if (collect->seen_segments)
+    g_list_free (collect->seen_segments);
+  collect->seen_segments = NULL;
+
   /* Expected segments */
   collect->expected_segments = g_list_append (collect->expected_segments,
       segment_new (1.0, GST_FORMAT_TIME, 0, 1 * GST_SECOND, 0));
@@ -672,7 +696,9 @@ GST_START_TEST (test_renegotiation)
   ASSERT_OBJECT_REFCOUNT_BETWEEN (bus, "main bus", 1, 2);
   gst_object_unref (bus);
 
-  g_free (collect);
+  collect_free (collect);
+
+  ges_deinit ();
 }
 
 GST_END_TEST;
@@ -684,6 +710,8 @@ GST_START_TEST (test_one_bin_space_another)
   gboolean ret = FALSE;
   GList *segments = NULL;
 
+  ges_init ();
+
   comp =
       gst_element_factory_make_or_warn ("nlecomposition", "test_composition");
   gst_element_set_state (comp, GST_STATE_READY);
@@ -743,6 +771,8 @@ GST_START_TEST (test_one_bin_space_another)
       segment_new (1.0, GST_FORMAT_TIME, 0, 1 * GST_SECOND, 0));
 
   fill_pipeline_and_check (comp, segments, GST_STREAM_ERROR);
+
+  ges_deinit ();
 }
 
 GST_END_TEST;
@@ -753,6 +783,8 @@ GST_START_TEST (test_one_above_another)
   gboolean ret = FALSE;
   GList *segments = NULL;
 
+  ges_init ();
+
   comp =
       gst_element_factory_make_or_warn ("nlecomposition", "test_composition");
   gst_element_set_state (comp, GST_STATE_READY);
@@ -814,6 +846,8 @@ GST_START_TEST (test_one_above_another)
           1 * GST_SECOND, 3 * GST_SECOND, 1 * GST_SECOND));
 
   fill_pipeline_and_check (comp, segments, 0);
+
+  ges_deinit ();
 }
 
 GST_END_TEST;
@@ -824,7 +858,6 @@ gnonlin_suite (void)
   Suite *s = suite_create ("gnonlin-complex");
   TCase *tc_chain = tcase_create ("complex");
 
-  ges_init ();
   suite_add_tcase (s, tc_chain);
 
   tcase_add_test (tc_chain, test_one_space_another);
