@@ -72,6 +72,10 @@ fill_pipeline_and_check (GstElement * comp, GList * segments)
 
   GST_DEBUG ("Resetted pipeline to READY");
 
+  if (collect->seen_segments)
+    g_list_free (collect->seen_segments);
+
+  collect->seen_segments = NULL;
   collect->expected_base = 0;
   collect->expected_segments = listcopy;
   collect->gotsegment = FALSE;
@@ -121,7 +125,7 @@ fill_pipeline_and_check (GstElement * comp, GList * segments)
   ASSERT_OBJECT_REFCOUNT_BETWEEN (bus, "main bus", 1, 2);
   gst_object_unref (bus);
 
-  g_free (collect);
+  collect_free (collect);
 }
 
 GST_START_TEST (test_simple_operation)
@@ -130,6 +134,8 @@ GST_START_TEST (test_simple_operation)
   GstElement *comp, *oper, *source;
   GList *segments = NULL;
 
+  ges_init ();
+
   comp =
       gst_element_factory_make_or_warn ("nlecomposition", "test_composition");
   gst_element_set_state (comp, GST_STATE_READY);
@@ -208,6 +214,8 @@ GST_START_TEST (test_simple_operation)
           2 * GST_SECOND, 3 * GST_SECOND, 2 * GST_SECOND));
 
   fill_pipeline_and_check (comp, segments);
+
+  ges_deinit ();
 }
 
 GST_END_TEST;
@@ -218,6 +226,8 @@ GST_START_TEST (test_pyramid_operations)
   gboolean ret = FALSE;
   GList *segments = NULL;
 
+  ges_init ();
+
   comp =
       gst_element_factory_make_or_warn ("nlecomposition", "test_composition");
   gst_element_set_state (comp, GST_STATE_READY);
@@ -300,6 +310,8 @@ GST_START_TEST (test_pyramid_operations)
           8 * GST_SECOND, 10 * GST_SECOND, 8 * GST_SECOND));
 
   fill_pipeline_and_check (comp, segments);
+
+  ges_deinit ();
 }
 
 GST_END_TEST;
@@ -310,6 +322,8 @@ GST_START_TEST (test_pyramid_operations2)
   GstElement *comp, *oper, *source1, *source2, *def;
   GList *segments = NULL;
 
+  ges_init ();
+
   comp =
       gst_element_factory_make_or_warn ("nlecomposition", "test_composition");
   gst_element_set_state (comp, GST_STATE_READY);
@@ -397,6 +411,8 @@ GST_START_TEST (test_pyramid_operations2)
           5 * GST_SECOND, 6 * GST_SECOND, 5 * GST_SECOND));
 
   fill_pipeline_and_check (comp, segments);
+
+  ges_deinit ();
 }
 
 GST_END_TEST;
@@ -407,6 +423,8 @@ GST_START_TEST (test_pyramid_operations_expandable)
   gboolean ret = FALSE;
   GList *segments = NULL;
 
+  ges_init ();
+
   comp =
       gst_element_factory_make_or_warn ("nlecomposition", "test_composition");
   gst_element_set_state (comp, GST_STATE_READY);
@@ -481,6 +499,8 @@ GST_START_TEST (test_pyramid_operations_expandable)
           4 * GST_SECOND, 6 * GST_SECOND, 4 * GST_SECOND));
 
   fill_pipeline_and_check (comp, segments);
+
+  ges_deinit ();
 }
 
 GST_END_TEST;
@@ -492,6 +512,8 @@ GST_START_TEST (test_complex_operations)
   gboolean ret = FALSE;
   GList *segments = NULL;
 
+  ges_init ();
+
   comp =
       gst_element_factory_make_or_warn ("nlecomposition", "test_composition");
   gst_element_set_state (comp, GST_STATE_READY);
@@ -545,12 +567,16 @@ GST_START_TEST (test_complex_operations)
   /* Add source1 */
   nle_composition_add (GST_BIN (comp), source1);
   check_start_stop_duration (comp, 0, 0, 0);
-  ASSERT_OBJECT_REFCOUNT (source1, "source1", 1);
+  /* If the composition already processed the source, the refcount
+   * might be 2 */
+  ASSERT_OBJECT_REFCOUNT_BETWEEN (source1, "source1", 1, 2);
 
   /* Add source2 */
   nle_composition_add (GST_BIN (comp), source2);
   check_start_stop_duration (comp, 0, 0, 0);
-  ASSERT_OBJECT_REFCOUNT (source2, "source2", 1);
+  /* If the composition already processed the source, the refcount
+   * might be 2 */
+  ASSERT_OBJECT_REFCOUNT_BETWEEN (source2, "source2", 1, 2);
 
   /* Add operaton */
   nle_composition_add (GST_BIN (comp), oper);
@@ -572,6 +598,8 @@ GST_START_TEST (test_complex_operations)
           4 * GST_SECOND, 6 * GST_SECOND, 4 * GST_SECOND));
 
   fill_pipeline_and_check (comp, segments);
+
+  ges_deinit ();
 }
 
 GST_END_TEST;
@@ -583,6 +611,8 @@ GST_START_TEST (test_complex_operations_bis)
   gboolean ret;
   GList *segments = NULL;
 
+  ges_init ();
+
   comp =
       gst_element_factory_make_or_warn ("nlecomposition", "test_composition");
   gst_element_set_state (comp, GST_STATE_READY);
@@ -672,6 +702,8 @@ GST_START_TEST (test_complex_operations_bis)
           0 * GST_SECOND, 2 * GST_SECOND, 4 * GST_SECOND));
 
   fill_pipeline_and_check (comp, segments);
+
+  ges_deinit ();
 }
 
 GST_END_TEST;
@@ -684,7 +716,6 @@ gnonlin_suite (void)
   Suite *s = suite_create ("nleoperation");
   TCase *tc_chain = tcase_create ("nleoperation");
 
-  ges_init ();
   suite_add_tcase (s, tc_chain);
 
   tcase_add_test (tc_chain, test_simple_operation);
